package com.zg.project.information.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zg.project.information.mapper.StockInTypeMapper;
import com.zg.project.information.domain.StockInType;
import com.zg.project.information.service.IStockInTypeService;

/**
 * 入库类型Service业务层处理
 * 
 * @author zg
 * @date 2025-05-27
 */
@Service
public class StockInTypeServiceImpl implements IStockInTypeService 
{
    @Autowired
    private StockInTypeMapper stockInTypeMapper;

    /**
     * 查询入库类型
     * 
     * @param id 入库类型主键
     * @return 入库类型
     */
    @Override
    public StockInType selectStockInTypeById(Long id)
    {
        return stockInTypeMapper.selectStockInTypeById(id);
    }

    /**
     * 查询入库类型列表
     * 
     * @param stockInType 入库类型
     * @return 入库类型
     */
    @Override
    public List<StockInType> selectStockInTypeList(StockInType stockInType)
    {
        return stockInTypeMapper.selectStockInTypeList(stockInType);
    }

    /**
     * 新增入库类型
     * 
     * @param stockInType 入库类型
     * @return 结果
     */
    @Override
    public int insertStockInType(StockInType stockInType)
    {
        return stockInTypeMapper.insertStockInType(stockInType);
    }

    /**
     * 修改入库类型
     * 
     * @param stockInType 入库类型
     * @return 结果
     */
    @Override
    public int updateStockInType(StockInType stockInType)
    {
        return stockInTypeMapper.updateStockInType(stockInType);
    }

    /**
     * 批量删除入库类型
     * 
     * @param ids 需要删除的入库类型主键
     * @return 结果
     */
    @Override
    public int deleteStockInTypeByIds(Long[] ids)
    {
        return stockInTypeMapper.deleteStockInTypeByIds(ids);
    }

    /**
     * 删除入库类型信息
     * 
     * @param id 入库类型主键
     * @return 结果
     */
    @Override
    public int deleteStockInTypeById(Long id)
    {
        return stockInTypeMapper.deleteStockInTypeById(id);
    }
}
